@@ -3,7 +3,7 @@ Apply a series of transformation functions to a given CSV column. This can be us
 perform typical data-wrangling tasks and/or to harmonize some values, etc.
 
 It has six subcommands:
- * operations - 34 string, format, currency, regex & NLP operators.
+ * operations - 35 string, format, currency, regex & NLP operators.
  * emptyreplace - replace empty cells with <--replacement> string.
  * datefmt - Formats a recognized date column to a specified format using <--formatstr>.
  * dynfmt - Dynamically constructs a new column from other columns using the <--formatstr> template.
@@ -52,6 +52,10 @@ It has 34 supported operations:
       Add additional comma-delimited profanities with -comparand. 
   * censor_count: count of profanities detected.
       Add additional comma-delimited profanities with -comparand. 
+  * thousands: Add thousands separator to numeric values.
+      Specify the separator policy with --comparand (default: comma). The valid policies are:
+      comma, dot, space, underscore, hex_four (place a space every four hex digits) and
+      indiancomma (place a comma every two digits, except the last three digits).
   * currencytonum: Gets the numeric value of a currency. Supports currency symbols
       (e.g. $,¥,£,€,֏,₱,₽,₪,₩,ƒ,฿,₫) and strings (e.g. USD, EUR, RMB, JPY, etc.). 
       Recognizes point, comma and space separators.
@@ -337,6 +341,7 @@ use strsim::{
     sorensen_dice,
 };
 use strum_macros::EnumString;
+use thousands::{policies, Separable, SeparatorPolicy};
 use titlecase::titlecase;
 use vader_sentiment::SentimentIntensityAnalyzer;
 use whatlang::detect;
@@ -383,6 +388,7 @@ enum Operations {
     Squeeze0,
     Strip_Prefix,
     Strip_Suffix,
+    Thousands,
     Titlecase,
     Trim,
     Upper,
@@ -421,11 +427,29 @@ static GEOCODER: OnceCell<ReverseGeocoder> = OnceCell::new();
 static EUDEX_COMPARAND_HASH: OnceCell<eudex::Hash> = OnceCell::new();
 static REGEX_REPLACE: OnceCell<Regex> = OnceCell::new();
 static SENTIMENT_ANALYZER: OnceCell<SentimentIntensityAnalyzer> = OnceCell::new();
+static THOUSANDS_POLICY: OnceCell<SeparatorPolicy> = OnceCell::new();
 static WHATLANG_CONFIDENCE_THRESHOLD: OnceCell<f64> = OnceCell::new();
 
 // default confidence threshold for whatlang language detection - 90% confidence
 const DEFAULT_THRESHOLD: f64 = 0.9;
 
+// for thousands operator
+static INDIANCOMMA_POLICY: SeparatorPolicy = SeparatorPolicy {
+    separator: ",",
+    groups:    &[3, 2],
+    digits:    thousands::digits::ASCII_DECIMAL,
+};
+
+// valid subcommands
+enum ApplySubCmd {
+    Operations,
+    DateFmt,
+    DynFmt,
+    Geocode,
+    EmptyReplace,
+    CalcConv,
+}
+
 #[inline]
 fn replace_column_value(
     record: &csv::StringRecord,
@@ -503,15 +527,6 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
         debug!("dynfmt_fields: {dynfmt_fields:?}  dynfmt_template: {dynfmt_template}");
     }
 
-    enum ApplySubCmd {
-        Operations,
-        DateFmt,
-        DynFmt,
-        Geocode,
-        EmptyReplace,
-        CalcConv,
-    }
-
     let mut ops_vec: Vec<Operations> = Vec::new();
 
     let apply_cmd = if args.cmd_operations {
@@ -610,8 +625,9 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
                         }
                     }
                     ApplySubCmd::Operations => {
+                        let mut cell = String::new();
                         for col_index in sel.iter() {
-                            let mut cell = record[*col_index].to_owned();
+                            record[*col_index].clone_into(&mut cell);
                             apply_operations(
                                 &ops_vec,
                                 &mut cell,
@@ -638,8 +654,9 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
                         }
                     }
                     ApplySubCmd::DateFmt => {
+                        let mut cell = String::new();
                         for col_index in sel.iter() {
-                            let mut cell = record[*col_index].to_owned();
+                            record[*col_index].clone_into(&mut cell);
                             if !cell.is_empty() {
                                 let parsed_date = parse_with_preference(&cell, prefer_dmy);
                                 if let Ok(format_date) = parsed_date {
@@ -870,6 +887,19 @@ fn validate_operations(
                 }
                 strip_invokes = strip_invokes.saturating_add(1);
             }
+            Operations::Thousands => {
+                let separator_policy = match flag_comparand.as_str() {
+                    "dot" => policies::DOT_SEPARATOR,
+                    "space" => policies::SPACE_SEPARATOR,
+                    "underscore" => policies::UNDERSCORE_SEPARATOR,
+                    "hexfour" => policies::HEX_FOUR,
+                    "indiancomma" => INDIANCOMMA_POLICY,
+                    _ => policies::COMMA_SEPARATOR,
+                };
+                if THOUSANDS_POLICY.set(separator_policy).is_err() {
+                    return fail!("Cannot initialize Thousands policy.");
+                };
+            }
             Operations::Whatlang => {
                 if flag_new_column.is_none() {
                     return fail!("--new_column (-c) is required for whatlang language detection.");
@@ -1028,6 +1058,11 @@ fn apply_operations(
                 let censor = CENSOR.get().unwrap();
                 *cell = censor.count(cell).to_string();
             }
+            Operations::Thousands => {
+                if let Ok(num) = cell.parse::<f64>() {
+                    *cell = num.separate_by_policy(*THOUSANDS_POLICY.get().unwrap());
+                }
+            }
             Operations::Currencytonum => {
                 // this is a workaround around current limitation of qsv-currency
                 // and also of upstream currency-rs, that it cannot
@@ -1154,6 +1189,8 @@ fn search_cached(cell: &str, formatstr: &str) -> Option<String> {
             let search_result = geocoder.search((lat, long));
             search_result.map(|locdetails| {
                 #[allow(clippy::match_same_arms)]
+                // match arms are evaluated in order,
+                // so we're optimizing for the most common cases first
                 match formatstr {
                     "%+" | "city-state" => format!(
                         "{name}, {admin1}",
@@ -1186,7 +1223,6 @@ fn search_cached(cell: &str, formatstr: &str) -> Option<String> {
                         cc = locdetails.record.cc
                     ),
                     "country" => locdetails.record.cc.to_string(),
-                    #[allow(clippy::match_same_arms)]
                     _ => locdetails.record.name.to_string(),
                 }
             })
