@@ -405,8 +405,9 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
                 let mut record = record_item.clone();
                 match applydp_cmd {
                     ApplydpSubCmd::Operations => {
+                        let mut cell = String::new();
                         for col_index in sel.iter() {
-                            let mut cell = record[*col_index].to_owned();
+                            record[*col_index].clone_into(&mut cell);
                             applydp_operations(
                                 &ops_vec,
                                 &mut cell,
@@ -432,8 +433,9 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
                         }
                     }
                     ApplydpSubCmd::DateFmt => {
+                        let mut cell = String::new();
                         for col_index in sel.iter() {
-                            let mut cell = record[*col_index].to_owned();
+                            record[*col_index].clone_into(&mut cell);
                             if !cell.is_empty() {
                                 let parsed_date = parse_with_preference(&cell, prefer_dmy);
                                 if let Ok(format_date) = parsed_date {
