@@ -1,3 +1,4 @@
+#![allow(unused_assignments)]
 static USAGE: &str = r#"
 Fetchpost fetches data from web services for every row using HTTP Post.
 As opposed to fetch, which uses HTTP Get.
@@ -27,8 +28,15 @@ QSV_FP_REDIS_TTL_REFRESH respectively to change default Redis settings.
 Supports brotli, gzip and deflate automatic decompression for improved throughput and
 performance, preferring brotli over gzip over deflate.
 
-Automatically upgrades its connection to HTTP/2 as well if the server supports it.
-(see https://www.cloudflare.com/learning/performance/http2-vs-http1.1/)
+Gzip compression of requests bodies is supported with the --compress flag. Note that
+public APIs typically do not support gzip compression of request bodies because of the
+"zip bomb" vulnerability. This option should only be used with private APIs where this
+is not a concern.
+
+Automatically upgrades its connection to HTTP/2 with adaptive flow control as well
+if the server supports it.
+See https://www.cloudflare.com/learning/performance/http2-vs-http1.1/ and
+https://medium.com/coderscorner/http-2-flow-control-77e54f7fd518 for more info.
 
 EXAMPLES:
 
@@ -159,7 +167,7 @@ Common options:
     -p, --progressbar          Show progress bars. Not valid for stdin.
 "#;
 
-use std::{fs, io::Write, thread, time};
+use std::{fs, io::Write, num::NonZeroU32, thread, time};
 
 use cached::{
     proc_macro::{cached, io_cached},
@@ -170,6 +178,7 @@ use governor::{
     clock::DefaultClock,
     middleware::NoOpMiddleware,
     state::{direct::NotKeyed, InMemoryState},
+    Quota, RateLimiter,
 };
 use indicatif::{HumanCount, MultiProgress, ProgressBar, ProgressDrawTarget};
 use log::{
@@ -180,7 +189,10 @@ use once_cell::sync::{Lazy, OnceCell};
 use rand::Rng;
 use redis;
 use regex::Regex;
-use reqwest::header::{HeaderMap, HeaderName, HeaderValue};
+use reqwest::{
+    blocking::Client,
+    header::{HeaderMap, HeaderName, HeaderValue},
+};
 use serde::{Deserialize, Serialize};
 use serde_json::{json, Value};
 use serde_urlencoded;
@@ -233,6 +245,18 @@ const FETCHPOST_REPORT_SUFFIX: &str = ".fetchpost-report.tsv";
 // prioritize decompression schemes. Brotli first, then gzip, then deflate, and * last
 static DEFAULT_ACCEPT_ENCODING: &str = "br;q=1.0, gzip;q=0.6, deflate;q=0.4, *;q=0.2";
 
+// for governor/ratelimiter
+const MINIMUM_WAIT_MS: u64 = 10;
+const MIN_WAIT: time::Duration = time::Duration::from_millis(MINIMUM_WAIT_MS);
+
+// for --report option
+#[derive(PartialEq)]
+enum ReportKind {
+    Detailed,
+    Short,
+    None,
+}
+
 struct RedisConfig {
     conn_str:      String,
     max_pool_size: u32,
@@ -367,7 +391,6 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
         }
     }
 
-    use std::num::NonZeroU32;
     let rate_limit = match args.flag_rate_limit {
         0 => NonZeroU32::new(u32::MAX).unwrap(),
         1..=1000 => NonZeroU32::new(args.flag_rate_limit).unwrap(),
@@ -432,8 +455,6 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
     };
     debug!("HTTP Header: {http_headers:?}");
 
-    use reqwest::blocking::Client;
-
     let client_timeout = time::Duration::from_secs(*TIMEOUT_FP_SECS.get().unwrap_or(&30));
     let client = Client::builder()
         .user_agent(user_agent)
@@ -448,8 +469,6 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
         .timeout(client_timeout)
         .build()?;
 
-    use governor::{Quota, RateLimiter};
-
     // set rate limiter with allow_burst set to 1 - see https://github.com/antifuchs/governor/issues/39
     let limiter =
         RateLimiter::direct(Quota::per_second(rate_limit).allow_burst(NonZeroU32::new(1).unwrap()));
@@ -491,13 +510,6 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
         None => args.flag_jql.as_ref().map(std::string::ToString::to_string),
     };
 
-    #[derive(PartialEq)]
-    enum ReportKind {
-        Detailed,
-        Short,
-        None,
-    }
-
     // prepare report
     let report = if args.flag_report.to_lowercase().starts_with('d') {
         // if it starts with d, its a detailed report
@@ -551,21 +563,15 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
     // we still optimize since fetch is backed by a memoized cache (in memory or Redis, when --redis
     // is used), so we want to return responses as fast as possible as we bypass the network
     // request with a cache hit
-    #[allow(unused_assignments)]
     let mut record = csv::ByteRecord::new();
-    #[allow(unused_assignments)]
     let mut jsonl_record = csv::ByteRecord::new();
-    #[allow(unused_assignments)]
     let mut report_record = csv::ByteRecord::new();
-    #[allow(unused_assignments)]
     let mut url = String::with_capacity(100);
     let mut redis_cache_hits: u64 = 0;
-    #[allow(unused_assignments)]
     let mut intermediate_redis_value: Return<String> = Return {
         was_cached: false,
         value:      String::new(),
     };
-    #[allow(unused_assignments)]
     let mut intermediate_value: Return<FetchResponse> = Return {
         was_cached: false,
         value:      FetchResponse {
@@ -574,9 +580,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
             retries:     0_u8,
         },
     };
-    #[allow(unused_assignments)]
     let mut final_value = String::with_capacity(150);
-    #[allow(unused_assignments)]
     let mut final_response = FetchResponse {
         response:    String::new(),
         status_code: 0_u16,
@@ -613,12 +617,14 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
                 serde_json::Value::String(value_string),
             );
         }
-        debug!("{form_body_jsonmap:?}");
+        if log::log_enabled!(Debug) {
+            debug!("{form_body_jsonmap:?}");
+        }
 
         if literal_url_used {
             url = literal_url.clone();
         } else if let Ok(s) = std::str::from_utf8(&record[column_index]) {
-            url = s.to_owned();
+            s.clone_into(&mut url);
         } else {
             url = String::new();
         }
@@ -922,8 +928,6 @@ fn get_response(
     info!("Using URL: {valid_url}");
 
     // wait until RateLimiter gives Okay or we timeout
-    const MINIMUM_WAIT_MS: u64 = 10;
-    const MIN_WAIT: time::Duration = time::Duration::from_millis(MINIMUM_WAIT_MS);
     let mut limiter_total_wait: u64;
     let timeout_secs = unsafe { *TIMEOUT_FP_SECS.get_unchecked() };
     let governor_timeout_ms = timeout_secs * 1_000;
