@@ -8,6 +8,8 @@ pub mod behead;
 pub mod cat;
 pub mod count;
 pub mod dedup;
+#[cfg(feature = "full")]
+pub mod diff;
 #[cfg(any(feature = "full", feature = "lite"))]
 pub mod enumerate;
 pub mod excel;
