@@ -1,9 +1,4 @@
-use crate::config::{Config, Delimiter};
-use crate::util;
-use crate::CliResult;
-use serde::Deserialize;
-
-static USAGE: &str = "
+static USAGE: &str = r#"
 Reverses rows of CSV data.
 
 Useful for cases when there is no column that can be used for sorting in reverse order,
@@ -13,6 +8,7 @@ Note that this requires reading all of the CSV data into memory.
 
 Usage:
     qsv reverse [options] [<input>]
+    qsv reverse --help
 
 Common options:
     -h, --help             Display this message
@@ -23,19 +19,27 @@ Common options:
                            appear as the header row in the output.
     -d, --delimiter <arg>  The field delimiter for reading CSV data.
                            Must be a single character. (default: ,)
-";
+"#;
+
+use serde::Deserialize;
+
+use crate::{
+    config::{Config, Delimiter},
+    util, CliResult,
+};
 
 #[derive(Deserialize)]
 struct Args {
-    arg_input: Option<String>,
-    flag_output: Option<String>,
+    arg_input:       Option<String>,
+    flag_output:     Option<String>,
     flag_no_headers: bool,
-    flag_delimiter: Option<Delimiter>,
+    flag_delimiter:  Option<Delimiter>,
 }
 
 pub fn run(argv: &[&str]) -> CliResult<()> {
     let args: Args = util::get_args(USAGE, argv)?;
     let rconfig = Config::new(&args.arg_input)
+        .checkutf8(false)
         .delimiter(args.flag_delimiter)
         .no_headers(args.flag_no_headers);
 
@@ -46,7 +50,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
 
     let mut wtr = Config::new(&args.flag_output).writer()?;
     rconfig.write_headers(&mut rdr, &mut wtr)?;
-    for r in all.into_iter() {
+    for r in all {
         wtr.write_byte_record(&r)?;
     }
     Ok(wtr.flush()?)
