@@ -120,7 +120,7 @@ Common options:
 // These "unsafe" calls primarily skip repetitive UTF-8 validation and unneeded bounds checking.
 //
 // To safeguard against undefined behavior, `stats` is the most extensively tested command,
-// with >425 tests.
+// with ~470 tests.
 
 use std::{
     borrow::ToOwned,
@@ -598,9 +598,6 @@ impl Stats {
         };
         if let Some(v) = self.minmax.as_mut() {
             if let Some(ts_val) = timestamp_val {
-                // TODO: is there a better, non-allocating way to do this?
-                // v.add(t, ts_val.to_string().as_bytes());
-                // informal benchmarking suggest itoa is a tad faster
                 let mut buffer = itoa::Buffer::new();
                 v.add(t, buffer.format(ts_val).as_bytes());
             } else {
@@ -949,12 +946,14 @@ impl Stats {
                             antimodes_list.push_str("*PREVIEW: ");
                         }
 
-                        antimodes_list.push_str(
-                            &antimodes_result
-                                .iter()
-                                .map(|c| String::from_utf8_lossy(c))
-                                .join(","),
-                        );
+                        let antimodes_vals = &antimodes_result
+                            .iter()
+                            .map(|c| String::from_utf8_lossy(c))
+                            .join(",");
+                        if antimodes_vals.starts_with(',') {
+                            antimodes_list.push_str("NULL");
+                        }
+                        antimodes_list.push_str(antimodes_vals);
 
                         // and truncate at 100 characters with an ellipsis
                         if antimodes_list.len() > 100 {
@@ -1065,6 +1064,9 @@ impl FieldType {
 impl Commute for FieldType {
     #[inline]
     #[allow(clippy::match_same_arms)]
+    // we allow match_same_arms because we want are optimizing for
+    // performance and not readability, as match arms are evaluated in order
+    // so we want to put the most common cases first
     fn merge(&mut self, other: FieldType) {
         *self = match (*self, other) {
             (TString, TString) => TString,
