@@ -1,3 +1,4 @@
+#![allow(unused_assignments)]
 static USAGE: &str = r#"
 Smartly converts CSV to a newline-delimited JSON (JSONL/NDJSON).
 
@@ -93,6 +94,9 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
     // we're calling the schema command to infer data types and enums
     let schema_args = crate::cmd::schema::Args {
         // we only do three, as we're only inferring boolean based on enum
+        // i.e. we only inspect a field if its boolean if its domain
+        // is just two values. if its more than 2, that's all we need know
+        // for boolean inferencing
         flag_enum_threshold:  3,
         flag_strict_dates:    false,
         flag_pattern_columns: crate::select::SelectColumns::parse("")?,
@@ -110,7 +114,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
         match infer_schema_from_stats(&schema_args, &input_filename) {
             Ok(map) => map,
             Err(e) => {
-                return fail_clierror!("Failed to infer field types via stats and frequency: {e}");
+                return fail_clierror!("Failed to infer field types: {e}");
             }
         };
 
@@ -214,21 +218,23 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
 
     // amortize allocs
     let mut record = csv::StringRecord::new();
-    #[allow(unused_assignments)]
-    let mut temp_str = String::with_capacity(100);
-    #[allow(unused_assignments)]
-    let mut temp_str2 = String::with_capacity(50);
+
+    let mut temp_string = String::with_capacity(100);
+    let mut temp_string2 = String::with_capacity(50);
+
+    let mut header_key = Value::String(String::with_capacity(50));
+    let mut temp_val = Value::String(String::with_capacity(50));
 
     // TODO: see if its worth it to do rayon here after benchmarking
     // with large files. We have --jobs option, but we only pass it
     // thru to stats/frequency to infer data types & enum constraints.
-    //
+
     // now that we have type mappings, iterate thru input csv
     // and write jsonl file
     while rdr.read_record(&mut record)? {
-        temp_str.clear();
+        temp_string.clear();
         record.trim();
-        write!(temp_str, "{{")?;
+        write!(temp_string, "{{")?;
         for (idx, field) in record.iter().enumerate() {
             let field_val = if let Some(field_type) = field_type_vec.get(idx) {
                 match field_type {
@@ -236,8 +242,11 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
                         if field.is_empty() {
                             "null"
                         } else {
-                            temp_str2 = format!(r#""{}""#, field.escape_default());
-                            &temp_str2
+                            // we round-trip thru serde_json to escape the str
+                            // per json spec (https://www.json.org/json-en.html)
+                            temp_val = field.into();
+                            temp_string2 = temp_val.to_string();
+                            &temp_string2
                         }
                     }
                     JsonlType::Null => "null",
@@ -253,16 +262,17 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
             } else {
                 "null"
             };
+            header_key = headers[idx].into();
             if field_val.is_empty() {
-                write!(temp_str, r#""{}":null,"#, &headers[idx])?;
+                write!(temp_string, r#"{header_key}:null,"#)?;
             } else {
-                write!(temp_str, r#""{}":{field_val},"#, &headers[idx])?;
+                write!(temp_string, r#"{header_key}:{field_val},"#)?;
             }
         }
-        temp_str.pop(); // remove last comma
-        temp_str.push('}');
+        temp_string.pop(); // remove last comma
+        temp_string.push('}');
         record.clear();
-        record.push_field(&temp_str);
+        record.push_field(&temp_string);
         wtr.write_record(&record)?;
     }
 
@@ -271,10 +281,5 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
 
 #[inline]
 fn first_lower_char(field_str: &str) -> char {
-    field_str
-        .trim_start()
-        .chars()
-        .next()
-        .unwrap_or('_')
-        .to_ascii_lowercase()
+    field_str.chars().next().unwrap_or('_').to_ascii_lowercase()
 }
