@@ -19,12 +19,17 @@ use crate::{
 const DEFAULT_RDR_BUFFER_CAPACITY: usize = 16 * (1 << 10);
 // previous wtr default in xsv is 32k, we're doubling it
 pub const DEFAULT_WTR_BUFFER_CAPACITY: usize = 64 * (1 << 10);
+
 // number of rows for qsv_sniffer to sample
 const DEFAULT_SNIFFER_SAMPLE: usize = 100;
+
 // for files, number of bytes to check for UTF8 encoding
 const DEFAULT_UTF8_CHECK_BUFFER_LEN: usize = 8192;
 const UTF8_ERROR_MSG: &str = "is not UTF-8 encoded. Use the input command to transcode to UTF-8.";
 
+// file size at which we warn user that a large file has not been indexed
+const NO_INDEX_WARNING_FILESIZE: u64 = 100_000_000; // 100MB
+
 #[derive(Clone, Copy, Debug)]
 pub struct Delimiter(pub u8);
 
@@ -66,7 +71,6 @@ impl<'de> Deserialize<'de> for Delimiter {
     }
 }
 
-#[allow(clippy::struct_excessive_bools)]
 #[derive(Debug)]
 pub struct Config {
     path:              Option<PathBuf>, // None implies <stdin>
@@ -430,11 +434,11 @@ impl Config {
         // modified, then return an error and demand the user regenerate the index.
         // Unless QSV_AUTOINDEX is set, in which case, we'll recreate the
         // stale index automatically
-        let data_modified = util::last_modified(&csv_file.metadata()?);
-        let idx_modified = util::last_modified(&idx_file.metadata()?);
+        let (data_modified, data_fsize) = util::file_metadata(&csv_file.metadata()?);
+        let (idx_modified, _) = util::file_metadata(&idx_file.metadata()?);
         if data_modified > idx_modified {
             if self.autoindex {
-                debug!("index stale... autoindexing...");
+                info!("index stale... autoindexing...");
                 self.autoindex_file();
             } else {
                 return Err(io::Error::new(
@@ -443,6 +447,18 @@ impl Config {
                 ));
             }
         }
+        // If the CSV file is larger than NO_INDEX_WARNING_FILESIZE,
+        // log a warning that the user should consider creating an index file for faster access.
+        if data_fsize > NO_INDEX_WARNING_FILESIZE {
+            use thousands::Separable;
+
+            warn!(
+                "The {} MB CSV file is larger than the {} MB NO_INDEX_WARNING_FILESIZE threshold. \
+                 Consider creating an index file for faster access.",
+                (data_fsize * 100).separate_with_commas(),
+                (NO_INDEX_WARNING_FILESIZE * 100).separate_with_commas()
+            );
+        }
         let csv_rdr = self.from_reader(csv_file);
         Ok(Some((csv_rdr, idx_file)))
     }
