@@ -1,10 +1,11 @@
-use std::cmp::Ordering;
-use std::collections::HashSet;
-use std::fmt;
-use std::iter::{self, repeat};
-use std::ops;
-use std::slice;
-use std::str::FromStr;
+use std::{
+    cmp::Ordering,
+    collections::HashSet,
+    fmt,
+    iter::{self, repeat},
+    ops, slice,
+    str::FromStr,
+};
 
 use regex::bytes::Regex;
 use serde::de::{Deserialize, Deserializer, Error};
@@ -12,7 +13,7 @@ use serde::de::{Deserialize, Deserializer, Error};
 #[derive(Clone)]
 pub struct SelectColumns {
     selectors: Vec<Selector>,
-    invert: bool,
+    invert:    bool,
 }
 
 impl SelectColumns {
@@ -82,36 +83,30 @@ impl fmt::Debug for SelectColumns {
 impl<'de> Deserialize<'de> for SelectColumns {
     fn deserialize<D: Deserializer<'de>>(d: D) -> Result<SelectColumns, D::Error> {
         let raw = String::deserialize(d)?;
-        SelectColumns::parse(&raw).map_err(|e| D::Error::custom(&e))
+        SelectColumns::parse(&raw).map_err(D::Error::custom)
     }
 }
 
 struct SelectorParser {
     chars: Vec<char>,
-    pos: usize,
+    pos:   usize,
 }
 
 impl SelectorParser {
     fn new(s: &str) -> SelectorParser {
         SelectorParser {
             chars: s.chars().collect(),
-            pos: 0,
+            pos:   0,
         }
     }
 
     fn parse(&mut self) -> Result<Vec<Selector>, String> {
         if (self.chars.first(), self.chars.last()) == (Some(&'/'), Some(&'/')) {
             if self.chars.len() == 2 {
-                return Err(format!(
-                    "Empty regex: {}",
-                    self.chars.iter().collect::<String>()
-                ));
+                return fail_format!("Empty regex: {}", self.chars.iter().collect::<String>());
             }
             let re: String = self.chars[1..(self.chars.len() - 1)].iter().collect();
-            let regex = match Regex::new(&re) {
-                Ok(r) => r,
-                Err(_) => return Err(format!("Invalid regex: {re}")),
-            };
+            let Ok(regex) = Regex::new(&re) else { return fail_format!("Invalid regex: {re}") };
             return Ok(vec![Selector::Regex(regex)]);
         }
 
@@ -136,10 +131,10 @@ impl SelectorParser {
                 None
             };
             if !self.is_end_of_selector() {
-                return Err(format!(
+                return fail_format!(
                     "Expected end of field but got '{}' instead.",
                     self.cur().unwrap()
-                ));
+                );
             }
             sels.push(match f2 {
                 Some(end) => Selector::Range(f1, end),
@@ -155,7 +150,7 @@ impl SelectorParser {
             self.bump();
             self.parse_quoted_name()?
         } else {
-            self.parse_name()?
+            self.parse_name()
         };
         Ok(if self.cur() == Some('[') {
             let idx = self.parse_index()?;
@@ -168,7 +163,7 @@ impl SelectorParser {
         })
     }
 
-    fn parse_name(&mut self) -> Result<String, String> {
+    fn parse_name(&mut self) -> String {
         let mut name = String::new();
         loop {
             if self.is_end_of_field() || self.cur() == Some('[') {
@@ -177,7 +172,7 @@ impl SelectorParser {
             name.push(self.cur().unwrap());
             self.bump();
         }
-        Ok(name)
+        name
     }
 
     fn parse_quoted_name(&mut self) -> Result<String, String> {
@@ -185,7 +180,7 @@ impl SelectorParser {
         loop {
             match self.cur() {
                 None => {
-                    return Err("Unclosed quote, missing closing \".".to_owned());
+                    return fail!("Unclosed quote, missing closing \".");
                 }
                 Some('"') => {
                     self.bump();
@@ -214,7 +209,7 @@ impl SelectorParser {
         loop {
             match self.cur() {
                 None => {
-                    return Err("Unclosed index bracket, missing closing ].".to_owned());
+                    return fail!("Unclosed index bracket, missing closing ].");
                 }
                 Some(']') => {
                     self.bump();
@@ -297,10 +292,9 @@ impl Selector {
                     .map(|(i, _)| i)
                     .collect();
                 if inds.is_empty() {
-                    return Err(format!(
-                        "Selector regex '{re}' does not match \
-                                        any columns in the CSV header."
-                    ));
+                    return fail_format!(
+                        "Selector regex '{re}' does not match any columns in the CSV header."
+                    );
                 }
                 Ok(inds)
             }
@@ -319,15 +313,13 @@ impl OneSelector {
             }),
             OneSelector::Index(i) => {
                 if first_record.is_empty() {
-                    return Err("Input is empty.".to_string());
+                    return fail!("Input is empty.");
                 }
                 if i < 1 || i > first_record.len() {
-                    Err(format!(
-                        "Selector index {i} is out of \
-                                 bounds. Index must be >= 1 \
-                                 and <= {}.",
+                    fail_format!(
+                        "Selector index {i} is out of bounds. Index must be >= 1 and <= {}.",
                         first_record.len()
-                    ))
+                    )
                 } else {
                     // Indices given by user are 1-offset. Convert them here!
                     Ok(i - 1)
@@ -335,10 +327,9 @@ impl OneSelector {
             }
             OneSelector::IndexedName(ref s, sidx) => {
                 if !use_names {
-                    return Err(format!(
-                        "Cannot use names ('{s}') in selection \
-                                        with --no-headers set."
-                    ));
+                    return fail_format!(
+                        "Cannot use names ('{s}') in selection with --no-headers set."
+                    );
                 }
                 let mut num_found = 0;
                 for (i, field) in first_record.iter().enumerate() {
@@ -350,17 +341,16 @@ impl OneSelector {
                     }
                 }
                 if num_found == 0 {
-                    Err(format!(
-                        "Selector name '{s}' does not exist \
-                                 as a named header in the given CSV \
-                                 data."
-                    ))
+                    fail_format!(
+                        "Selector name '{s}' does not exist as a named header in the given CSV \
+                         data."
+                    )
                 } else {
-                    Err(format!(
-                        "Selector index '{sidx}' for name '{s}' is \
-                                 out of bounds. Must be >= 0 and <= {}.",
+                    fail_format!(
+                        "Selector index '{sidx}' for name '{s}' is out of bounds. Must be >= 0 \
+                         and <= {}.",
                         num_found - 1
-                    ))
+                    )
                 }
             }
         }
@@ -399,6 +389,8 @@ impl Selection {
         row: &'b csv::ByteRecord,
     ) -> iter::Scan<slice::Iter<'a, usize>, &'b csv::ByteRecord, _GetField> {
         // This is horrifying.
+        #[allow(clippy::unnecessary_wraps)]
+        #[allow(clippy::trivially_copy_pass_by_ref)]
         fn get_field<'c>(row: &mut &'c csv::ByteRecord, idx: &usize) -> Option<&'c [u8]> {
             Some(&row[*idx])
         }
@@ -407,7 +399,7 @@ impl Selection {
     }
 
     pub fn normal(&self) -> NormalSelection {
-        let &Selection(ref inds) = self;
+        let Selection(inds) = self;
         if inds.is_empty() {
             return NormalSelection(vec![]);
         }
@@ -451,9 +443,11 @@ impl NormalSelection {
     where
         I: Iterator<Item = T>,
     {
-        fn filmap<T>(v: Option<T>) -> Option<T> {
+        const fn filmap<T>(v: Option<T>) -> Option<T> {
             v
         }
+        #[allow(clippy::option_option)]
+        #[allow(clippy::unnecessary_wraps)]
         fn get_field<T>(set: &mut &[bool], t: (usize, T)) -> Option<Option<T>> {
             let (i, v) = t;
             if i < set.len() && set[i] {
