@@ -336,10 +336,11 @@ pub const fn num_of_chunks(nitems: usize, chunk_size: usize) -> usize {
     n
 }
 
-#[allow(clippy::cast_sign_loss)]
-pub fn last_modified(md: &fs::Metadata) -> u64 {
+pub fn file_metadata(md: &fs::Metadata) -> (u64, u64) {
     use filetime::FileTime;
-    FileTime::from_last_modification_time(md).unix_seconds() as u64
+    let last_modified = FileTime::from_last_modification_time(md).unix_seconds() as u64;
+    let fsize = md.len();
+    (last_modified, fsize)
 }
 
 #[cfg(any(feature = "full", feature = "lite"))]
@@ -527,6 +528,10 @@ pub fn init_logger() -> String {
 
 #[cfg(feature = "self_update")]
 pub fn qsv_check_for_update(check_only: bool, no_confirm: bool) -> Result<bool, String> {
+    use self_update::cargo_crate_version;
+    const GITHUB_RATELIMIT_MSG: &str =
+        "Github is rate-limiting self-update checks at the moment. Try again in an hour.";
+
     if env::var("QSV_NO_UPDATE").is_ok() {
         return Ok(false);
     }
@@ -544,10 +549,6 @@ pub fn qsv_check_for_update(check_only: bool, no_confirm: bool) -> Result<bool,
 
     winfo!("Checking GitHub for updates...");
 
-    use self_update::cargo_crate_version;
-    const GITHUB_RATELIMIT_MSG: &str =
-        "Github is rate-limiting self-update checks at the moment. Try again in an hour.";
-
     let curr_version = cargo_crate_version!();
     let releases = if let Ok(releases_list) =
         self_update::backends::github::ReleaseList::configure()
@@ -606,7 +607,7 @@ pub fn qsv_check_for_update(check_only: bool, no_confirm: bool) -> Result<bool,
             winfo!(
                 r#"This qsv was {QSV_KIND}. self-update does not work for manually {QSV_KIND} binaries.
 If you wish to update to the latest version of qsv, manually install/compile from source
-or download the prebuilt binaries from GitHub."#
+or download the latest prebuilt binaries from GitHub - https://github.com/jqnatividad/qsv/releases/latest"#
             );
         }
     } else {
